{% extends "blog/blog_post_list.html" %}
{% load mezzanine_tags comment_tags keyword_tags rating_tags i18n future disqus_tags %}

{% block meta_title %}{{ blog_post.meta_title }}{% endblock %}

{% block meta_keywords %}{% metablock %}
{% keywords_for blog_post as tags %}
{% for tag in tags %}{% if not forloop.first %}, {% endif %}{{ tag }}{% endfor %}
{% endmetablock %}{% endblock %}

{% block meta_description %}{% metablock %}
{{ blog_post.description }}
{% endmetablock %}{% endblock %}

{% block title %}
{% editable blog_post.title %}{{ blog_post.title }}{% endeditable %}
{% endblock %}

{% block breadcrumb_menu %}
{{ block.super }}
<li class="active">{{ blog_post.title }}</li>
{% endblock %}

{% block main %}

{% block blog_post_detail_postedby %}
{% editable blog_post.publish_date %}
<h6>
    {% trans "Posted by" %}:
    {% with blog_post.user as author %}
    <a href="{% url "blog_post_list_author" author %}">{{ author.get_full_name|default:author.username }}</a>
    {% endwith %}
    {% blocktrans with sometime=blog_post.publish_date|timesince %}{{ sometime }} ago{% endblocktrans %}
</h6>
{% endeditable %}
{% endblock %}
{% block blog_post_detail_commentlink %}
<p>
    {% if blog_post.allow_comments %}
        {% if settings.COMMENTS_DISQUS_SHORTNAME %}
            (<a href="{{ blog_post.get_absolute_url }}#disqus_thread"
                data-disqus-identifier="{% disqus_id_for blog_post %}">{% spaceless %}
                {% trans "Comments" %}
            {% endspaceless %}</a>)
        {% else %}(<a href="#comments">{% spaceless %}
            {% blocktrans count blog_post.comments_count as comments_count %}1 comment{% plural %}{{ comments_count }} comments{% endblocktrans %}
            {% endspaceless %}</a>)
        {% endif %}
    {% endif %}
</p>
{% endblock %}

{% block extension_1 %}{% endblock %}

{% block blog_post_detail_featured_image %}
{% if blog_post.featured_image %}
<p><img src="{{ MEDIA_URL }}{% thumbnail blog_post.featured_image 720 0 %}"></p>
{% endif %}
{% endblock %}

{% if settings.COMMENTS_DISQUS_SHORTNAME %}
{% include "generic/includes/disqus_counts.html" %}
{% endif %}

{% block extension_2 %}{% endblock %}

{% block blog_post_detail_content %}
{% editable blog_post.content %}
{{ blog_post.content|richtext_filter|safe }}
{% endeditable %}
{% endblock %}

{% block blog_post_detail_keywords %}
{% keywords_for blog_post as tags %}
{% if tags %}
{% spaceless %}
<ul class="unstyled tags">
    <li>{% trans "Tags" %}:</li>
    {% for tag in tags %}
    <li><a href="{% url "blog_post_list_tag" tag.slug %}">{{ tag }}</a></li>
    {% endfor %}
</ul>
{% endspaceless %}
{% endif %}
{% endblock %}

{% rating_for blog_post %}

{% block blog_post_detail_sharebuttons %}
{% set_short_url_for blog_post %}
<a class="btn small primary share-twitter" target="_blank" href="http://twitter.com/home?status={{ blog_post.short_url|urlencode }}%20{{ blog_post.title|urlencode }}">{% trans "Share on Twitter" %}</a>
<a class="btn small primary share-facebook" target="_blank" href="http://facebook.com/sharer.php?u={{ request.build_absolute_uri }}&amp;t={{ blog_post.title|urlencode }}">{% trans "Share on Facebook" %}</a>
{% endblock %}

{% block blog_post_previous_next %}
<ul class="pager">
{% with blog_post.get_previous_by_publish_date as previous %}
{% if previous %}
<li class="previous">
    <a href="{{ previous.get_absolute_url }}">&larr; {{ previous }}</a>
</li>
{% endif %}
{% endwith %}
{% with blog_post.get_next_by_publish_date as next %}
{% if next %}
<li class="next">
    <a href="{{ next.get_absolute_url }}">{{ next }} &rarr;</a>
</li>
{% endif %}
{% endwith %}
</ul>
{% endblock %}

{% block extension_3 %}{% endblock %}

{% block blog_post_detail_related_posts %}
{% if blog_post.related_posts.all %}
<div id="related-posts">
<h3>{% trans 'Related posts' %}</h3>
<ul class="unstyled">
{% for post in blog_post.related_posts.all %}
     <li><a href="{{ post.get_absolute_url }}">{{ post.title }}</a></li>
{% endfor %}
</ul>
</div>
{% endif %}
{% endblock %}

{% block extension_4 %}{% endblock %}

{% block blog_post_detail_comments %}
{% if blog_post.allow_comments %}{% comments_for blog_post %}{% endif %}
{% endblock %}

{% endblock %}
